package com.ruoyi.ptxlib;

import cn.hutool.core.util.StrUtil;

import java.io.UnsupportedEncodingException;
import java.nio.charset.StandardCharsets;

public class PTXService {
    /**
     * 创建表单
     *
     * @param pid 分辨率
     */
    public void createForm(String pid)
    {
        if (pid == null) {
            pid = "300";
        }
        String cmd = "~CREATE;formName;X\r\nSCALE;DOT;" + pid + ";" + pid + "\r\nFONT;SYMSET 'UTF8'\r\n";//创建表单，分辨率为203，如是300点机器，请改为300;300
        PTXLib.INSTANCE.sendcommand(cmd);
    }

    /**
     * 字体加粗
     *
     * @param bold 是否加粗
     */
    public void setBold(boolean bold)
    {
        String cmd;
        if (bold)
        {
            cmd = "FONT;NAME 92244.sf;BOLD 1\r\n";
        }
        else
        {
            cmd = "FONT;NAME 92244.sf;BOLD 0\r\n";
        }
        PTXLib.INSTANCE.sendcommand(cmd);

    }

    /**
     * 打印表单
     */
    public void printForm()
    {
        String cmd = "END\r\n~EXECUTE;formName\r\n~NORMAL\r\n";
        PTXLib.INSTANCE.sendcommand(cmd);
    }

    /**
     * 使用中文字体进行打印
     *
     * @param X x轴坐标
     * @param Y y轴坐标
     * @param VE x轴垂直扩展间距 行高
     * @param he Y轴垂直扩展间距 行高
     * @param data 打印数据
     */
    public void printText(String X,String Y,String VE,String he,String data) {
        //使用字体为SIMHEI.TTF来打印中文，如打印内容中包含*，请修改data前后的*，变为内容中不会包含的符号
        String cmd = "FONT;NAME SIMHEI.TTF\r\nTWOBYTE\r\nPOINT;"+Y+";"+X+";"+VE+";"+he+";*"+data+"*\r\nSTOP\r\n";

        byte[] data1 = new byte[1024];
        try {
            data1=cmd.getBytes("UTF-8");
        } catch (UnsupportedEncodingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        PTXLib.INSTANCE.sendBinaryDataNoCRLF(data1,data1.length);
    }

    /**
     * 使用内部字体打印英文
     *
     * @param X x轴坐标
     * @param Y y轴坐标
     * @param VE x轴垂直扩展间距 行高
     * @param he Y轴垂直扩展间距 行高
     * @param data 打印数据
     */
    public void printTextEn(String X,String Y,String VE,String he,String data)
    {
        String cmd = "ALPHA\r\nPOINT;"+Y+";"+X+";"+VE+";"+he+";*"+data+"*\r\nSTOP\r\n";//仅可用来打印英文及数字，如打印内容中包含*，请修改data前后的*，变为内容中不会包含的符号
        //PTXLIBDLL.INSTANCE.sendcommand(cmd);
        byte[] data1 = new byte[1024];
        data1=cmd.getBytes(StandardCharsets.UTF_8);
        PTXLib.INSTANCE.sendBinaryDataNoCRLF(data1,data1.length);
    }

    public void writeRFID(String EPC) {
        String RFID_format = "H"; // 十六进
        String regex="^[A-Fa-f0-9]+$";

        if (StrUtil.isBlank(EPC)) {
            throw new RuntimeException("EPC不能为空");
        }
        if (EPC.length() % 4 != 0) {
            throw new RuntimeException("EPC的长度必须为4的倍数");
        }

        // 大写英文
        EPC = EPC.toUpperCase();

        if (!EPC.matches(regex)) {
            throw new RuntimeException("非正则表达式");
        }

        String cmd2="RFWTAG;96;EPC\n96;"+ RFID_format +";*"+EPC+"*\nSTOP\n";//向EPC内写入数据指令，其中的96参数为写入数据长度*4

        // 将EPC写入指令发送至打印机，其余PGL指令均可有sendcommand方法发送至打印机内使用
        PTXLib.INSTANCE.sendcommand(cmd2);
    }

    /**
     * 打印二维码
     *
     * @param X
     * @param Y
     * @param width
     * @param data
     */
    public void printQrCode(String X,String Y,String width,String data)
    {

        String cmd = "BARCODE\r\nQRCODE;XD"+width+";"+Y+";"+X+"\r\n*"+data+"*\r\nSTOP\r\n";//打印QRCODE二维码，如打印内容中包含*，请修改data前后的*，变为内容中不会包含的符号
        byte[] data1 = new byte[1024];
        try {
            data1=cmd.getBytes("UTF-8");
        } catch (UnsupportedEncodingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        PTXLib.INSTANCE.sendBinaryDataNoCRLF(data1,data1.length);
    }

    /**
     * 打印128一维码
     *
     * @param X
     * @param Y
     * @param width
     * @param data
     * @param read
     * @param high
     */
    public void printCode128(String X,String Y,int width,String data,Boolean read,double high)
    {
        String cmd;
        if(read){
            cmd = "BARCODE\r\nC128A;XRD" + width * 1 + ":" + width * 1 + ":" + width * 2 + ":" + width * 2 + ":" + width * 3 + ":" + width * 3 + ":" + width * 4 + ":" + width * 4 + ";H" + high + ";" + Y + ";" + X + "\r\n*" + data + "*\r\nPDF\r\nSTOP\r\n";
        }
        else{
            cmd = "BARCODE\r\nC128A;XRD" + width * 1 + ":" + width * 1 + ":" + width * 2 + ":" + width * 2 + ":" + width * 3 + ":" + width * 3 + ":" + width * 4 + ":" + width * 4 + ";H" + high + ";" + Y + ";" + X + "\r\n*" + data + "*\r\nSTOP\r\n";
        }
        PTXLib.INSTANCE.sendcommand(cmd);

    }
}
